# Label Widgets

Interactive and customizable labels: clickable tags, framed labels,
labels with hover icons and LED status indicators.

---

## ClickableTagLabel

::: ezqt_widgets.label.clickable_tag_label.ClickableTagLabel

---

## FramedLabel

::: ezqt_widgets.label.framed_label.FramedLabel

---

## HoverLabel

::: ezqt_widgets.label.hover_label.HoverLabel

---

## IndicatorLabel

::: ezqt_widgets.label.indicator_label.IndicatorLabel
